android constant

String const android

The value of operatingSystem on Android.

Can be used, for example, in switch cases when switching on operatingSystem.

Use isAndroid as a direct way to check whether the platform is Android.

Implementation

static const String android = 'android';