isLinux property
Whether the operating system is Linux.
The operating system is determined by operatingSystem, and is recognized as Linux if the value is the string linux.
Implementation
abstract final bool isLinux;
Whether the operating system is Linux.
The operating system is determined by operatingSystem, and is recognized as Linux if the value is the string linux.
abstract final bool isLinux;