operatingSystemVersion property

  1. @Deprecated('Use NativePlatform.current!.operatingSystemVersion instead')
String get operatingSystemVersion
inherited

A string representing the version of the operating system or platform.

Warning

This property is deprecated on Platform. It is only implemented by the legacy LocalPlatform and FakePlatform classes, and cannot be accessed through Platform.current. Use NativePlatform to access these properties instead, accessed as NativePlatform.current.

Implementation

@Deprecated('Use NativePlatform.current!.operatingSystemVersion instead')
String get operatingSystemVersion => throw UnimplementedError(
  'Use NativePlatform.current!.operatingSystemVersion instead',
);