pathSeparator property

  1. @Deprecated('Use NativePlatform.current!.pathSeparator instead')
String get pathSeparator
inherited

The path separator used by the operating system to separate components in file paths.

Warning

This property is deprecated on Platform. It is only implemented by the legacy LocalPlatform and FakePlatform classes, and cannot be accessed through Platform.current. Use NativePlatform to access these properties instead, accessed as NativePlatform.current.

Implementation

@Deprecated('Use NativePlatform.current!.pathSeparator instead')
String get pathSeparator => throw UnimplementedError(
  'Use NativePlatform.current!.pathSeparator instead',
);