stdoutSupportsAnsi property

  1. @Deprecated('Use NativePlatform.current!.stdoutSupportsAnsi instead')
bool get stdoutSupportsAnsi
inherited

When stdout is connected to a terminal, whether ANSI codes are supported.

Warning

This property is deprecated on Platform. It is only implemented by the legacy LocalPlatform and FakePlatform classes, and cannot be accessed through Platform.current. Use NativePlatform to access these properties instead, accessed as NativePlatform.current.

Implementation

@Deprecated('Use NativePlatform.current!.stdoutSupportsAnsi instead')
bool get stdoutSupportsAnsi => throw UnimplementedError(
  'Use NativePlatform.current!.stdoutSupportsAnsi instead',
);