TestBrowserPlatform constructor

  1. @visibleForTesting
TestBrowserPlatform({
  1. String? version,
  2. String? userAgent,
})

Creates a custom TestBrowserPlatform with the given properties.

If an argument is omitted or null, the created object will throw an error when reading the corresponding property.

Implementation

@visibleForTesting
TestBrowserPlatform({String? version, String? userAgent})
  : _version = version,
    _userAgent = userAgent;