version property
The browser's version, as reported by Navigator.appVersion by default.
If a particular browser provides a more specific version string, it may be used instead of the default.
No guarantees are made about the format of the string, it may differ between different browser types, and between different browser versions or versions of this package.
If no Navigator object is a available,
the string content is unspecified.
Implementation
@override
String get version => _throwIfUnset(_version, _className, json_key.version);