bind<R> method
- @visibleForTesting
- R withOverride()
Wraps withOverride to run it with this native platform as current.
The returned function runs withOverride through run every time it's
called, to ensure all the calls will see the same override.
Implementation
@visibleForTesting
R Function() bind<R>(R Function() withOverride) =>
() => run(withOverride);