executable property

  1. @override
String get executable
override

The file path of the executable used to run the script in this isolate.

The file path returned is the literal path used to run the script. This path might be relative or just be a name from which the executable was found by searching the system path.

For the absolute path to the resolved executable use resolvedExecutable.

Implementation

@override
String get executable =>
    _throwIfUnset(_executable, _className, json_key.executable);