executableArguments property

  1. @override
List<String> get executableArguments
override

The flags passed to the executable used to run the script of this program.

These are the command-line entries between the executable name and the script name. Each access to executableArguments returns a new list containing the flags passed to the executable.

Implementation

@override
List<String> get executableArguments => _throwIfUnset<List<String>>(
  _executableArguments,
  _className,
  json_key.executableArguments,
);