operatingSystem property

  1. @override
String get operatingSystem
override

A string representing the operating system.

The currently possible return values are available from operatingSystemValues, and there are constants for each of the platforms to use in switch statements or conditionals (See linux, macOS, windows, android, iOS and fuchsia).

Implementation

@override
String get operatingSystem =>
    _throwIfUnset(_operatingSystem, _className, json_key.operatingSystem);