script property

  1. @override
Uri get script
override

The absolute URI of the script file of the program currently running.

The Uri is empty if the executable environment does not provide the location of a script. Otherwise the value is what the platform provides, which is usually the Platform.script value of dart:io.

Implementation

@override
Uri get script => _throwIfUnset(_script, _className, json_key.script);