TestPlatform.unknown constructor
- @visibleForTesting
A platform with neither the native or the browser platform available.
Implementation
@visibleForTesting
const TestPlatform.unknown() : nativePlatform = null, browserPlatform = null;
A platform with neither the native or the browser platform available.
@visibleForTesting
const TestPlatform.unknown() : nativePlatform = null, browserPlatform = null;