browserPlatform property
The current browser platform, if running on a browser platform.
Implementation
@override
final TestBrowserPlatform? browserPlatform;
The current browser platform, if running on a browser platform.
@override
final TestBrowserPlatform? browserPlatform;