nativePlatform property
The current native platform, if running on a native platform.
Implementation
@override
final TestNativePlatform? nativePlatform;
The current native platform, if running on a native platform.
@override
final TestNativePlatform? nativePlatform;