resolvedExecutable property
- @Deprecated('Use NativePlatform.current!.resolvedExecutable instead')
inherited
The path of the executable used to run the script in this isolate after it has been resolved by the OS.
Warning
This property is deprecated on Platform.
It is only implemented by the legacy LocalPlatform and FakePlatform
classes, and cannot be accessed through Platform.current.
Use NativePlatform to access these properties instead, accessed as
NativePlatform.current.
This is the absolute path, with all symlinks resolved, to the executable used to run the script.
Implementation
@Deprecated('Use NativePlatform.current!.resolvedExecutable instead')
String get resolvedExecutable => throw UnimplementedError(
'Use NativePlatform.current!.resolvedExecutable instead',
);